@@ -5,10 +5,8 @@ use std::io::{Read, Write};
 
 use byteorder::{ReadBytesExt, WriteBytesExt};
 
-use util::Error;
-
 use super::content::*;
-use super::errors::*;
+use super::error::*;
 
 // The change cipher spec protocol exists to signal transitions in
 // ciphering strategies.  The protocol consists of a single message,
@@ -36,7 +34,7 @@ impl ChangeCipherSpec {
     pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self, Error> {
         let data = reader.read_u8()?;
         if data != 0x01 {
-            return Err(ERR_INVALID_CIPHER_SPEC.clone());
+            return Err(Error::ErrInvalidCipherSpec);
         }
 
         Ok(ChangeCipherSpec {})
