@@ -2,8 +2,6 @@ use super::*;
 
 use std::io::{BufReader, BufWriter};
 
-use util::Error;
-
 #[test]
 fn test_change_cipher_spec_round_trip() -> Result<(), Error> {
     let c = ChangeCipherSpec {};
@@ -33,7 +31,7 @@ fn test_change_cipher_spec_invalid() -> Result<(), Error> {
 
     match result {
         Ok(_) => assert!(false, "must be error"),
-        Err(err) => assert_eq!(err, *ERR_INVALID_CIPHER_SPEC),
+        Err(err) => assert_eq!(err.to_string(), Error::ErrInvalidCipherSpec.to_string()),
     };
 
     Ok(())
