@@ -1,18 +1,18 @@
 use super::cipher_suite::*;
 use super::conn::*;
 use super::curve::named_curve::*;
-use super::errors::*;
 use super::extension::extension_use_srtp::SrtpProtectionProfile;
 use super::handshake::handshake_random::*;
 use super::prf::*;
+use crate::error::Error;
 
-use util::Error;
+use srtp::config::KeyingMaterialExporter;
 
+use async_trait::async_trait;
 use std::io::{BufWriter, Cursor};
 use std::marker::{Send, Sync};
 use std::sync::atomic::{AtomicU16, Ordering};
 use std::sync::Arc;
-
 use tokio::sync::Mutex;
 
 // State holds the dtls connection state and implements both encoding.BinaryMarshaler and encoding.BinaryUnmarshaler
@@ -135,7 +135,7 @@ impl State {
             let cipher_suite = self.cipher_suite.lock().await;
             match &*cipher_suite {
                 Some(cipher_suite) => cipher_suite.id() as u16,
-                None => return Err(ERR_CIPHER_SUITE_UNSET.clone()),
+                None => return Err(Error::ErrCipherSuiteUnset),
             }
         };
 
@@ -216,7 +216,7 @@ impl State {
                 cipher_suite.init(&self.master_secret, &remote_random, &local_random, false)
             }
         } else {
-            Err(ERR_CIPHER_SUITE_UNSET.clone())
+            Err(Error::ErrCipherSuiteUnset)
         }
     }
 
@@ -226,7 +226,7 @@ impl State {
 
         match bincode::serialize(&serialized) {
             Ok(enc) => Ok(enc),
-            Err(err) => Err(Error::new(err.to_string())),
+            Err(err) => Err(Error::ErrOthers(err.to_string())),
         }
     }
 
@@ -234,41 +234,54 @@ impl State {
     pub async fn unmarshal_binary(&mut self, data: &[u8]) -> Result<(), Error> {
         let serialized: SerializedState = match bincode::deserialize(data) {
             Ok(dec) => dec,
-            Err(err) => return Err(Error::new(err.to_string())),
+            Err(err) => return Err(Error::ErrOthers(err.to_string())),
         };
         self.deserialize(&serialized).await?;
         self.init_cipher_suite().await?;
 
         Ok(())
     }
+}
 
-    // export_keying_material returns length bytes of exported key material in a new
-    // slice as defined in RFC 5705.
-    // This allows protocols to use DTLS for key establishment, but
-    // then use some of the keying material for their own purposes
-    pub async fn export_keying_material(
+#[async_trait]
+impl KeyingMaterialExporter for State {
+    /// export_keying_material returns length bytes of exported key material in a new
+    /// slice as defined in RFC 5705.
+    /// This allows protocols to use DTLS for key establishment, but
+    /// then use some of the keying material for their own purposes
+    async fn export_keying_material(
         &self,
         label: &str,
         context: &[u8],
         length: usize,
-    ) -> Result<Vec<u8>, Error> {
+    ) -> Result<Vec<u8>, srtp::error::Error> {
         if self.local_epoch.load(Ordering::Relaxed) == 0 {
-            return Err(ERR_HANDSHAKE_IN_PROGRESS.clone());
+            return Err(srtp::error::Error::ErrOthers(
+                Error::ErrHandshakeInProgress.to_string(),
+            ));
         } else if !context.is_empty() {
-            return Err(ERR_CONTEXT_UNSUPPORTED.clone());
+            return Err(srtp::error::Error::ErrOthers(
+                Error::ErrContextUnsupported.to_string(),
+            ));
         } else if INVALID_KEYING_LABELS.contains_key(label) {
-            return Err(ERR_RESERVED_EXPORT_KEYING_MATERIAL.clone());
+            return Err(srtp::error::Error::ErrOthers(
+                Error::ErrReservedExportKeyingMaterial.to_string(),
+            ));
         }
 
         let mut local_random = vec![];
         {
             let mut writer = BufWriter::<&mut Vec<u8>>::new(local_random.as_mut());
-            self.local_random.marshal(&mut writer)?;
+            if let Err(err) = self.local_random.marshal(&mut writer) {
+                return Err(srtp::error::Error::ErrOthers(err.to_string()));
+            }
         }
         let mut remote_random = vec![];
         {
             let mut writer = BufWriter::<&mut Vec<u8>>::new(remote_random.as_mut());
-            self.remote_random.marshal(&mut writer)?;
+            if let Err(err) = self.remote_random.marshal(&mut writer) {
+                return Err(srtp::error::Error::ErrOthers(err.to_string()));
+            }
         }
 
         let mut seed = label.as_bytes().to_vec();
@@ -282,9 +295,14 @@ impl State {
 
         let cipher_suite = self.cipher_suite.lock().await;
         if let Some(cipher_suite) = &*cipher_suite {
-            prf_p_hash(&self.master_secret, &seed, length, cipher_suite.hash_func())
+            match prf_p_hash(&self.master_secret, &seed, length, cipher_suite.hash_func()) {
+                Ok(v) => Ok(v),
+                Err(err) => Err(srtp::error::Error::ErrOthers(err.to_string())),
+            }
         } else {
-            Err(ERR_CIPHER_SUITE_UNSET.clone())
+            Err(srtp::error::Error::ErrOthers(
+                Error::ErrCipherSuiteUnset.to_string(),
+            ))
         }
     }
 }
